from django.db import models
from django.core.validators import RegexValidator, MinLengthValidator, \
    MaxLengthValidator
from django.utils.translation import ugettext_lazy as _, pgettext_lazy

from authentic2.models import AbstractUser

class Citoyen(AbstractUser):
    title = models.CharField(pgettext_lazy('person title', 'title'), max_length=16, blank=True,
            choices=tuple((x, x) for x in (_('Mr'),
                     _('Mrs'),
                     _('Miss'))))

    first_name = models.CharField(_('first name'), max_length=30, blank=True)
    last_name = models.CharField(_('last name'), max_length=30, blank=True)
    email = models.EmailField(_('e-mail address'), max_length=128, blank=True)
    city = models.CharField(_('city'), max_length=64, blank=True)
    address = models.CharField(_('address'), max_length=128, blank=True)
    postal_code = models.CharField(_('postal code'), max_length=5, blank=True,
            validators=[
                RegexValidator(r'^[0-9]*$',
                    _('Postal code must be five numbers'),
                    _('Invalid postal code')),
                MinLengthValidator(5),
                MaxLengthValidator(5)])
    phone = models.CharField(verbose_name=_("phone"),
            max_length=16, blank=True)
    mobile = models.CharField(verbose_name=_("mobile"),
            max_length=16, blank=True)

    REQUIRED_FIELDS = ['first_name', 'last_name', 'email']

    USER_PROFILE = ( 'title', 'username', 'first_name', 'last_name', 'email',
            'phone', 'mobile', 'address', 'postal_code', 'city')

from authentic2.attribute_aggregator.core import ATTRIBUTE_MAPPING

ATTRIBUTE_MAPPING['l']['profile_field_name'] = 'city'
ATTRIBUTE_MAPPING['personalTitle']['profile_field_name'] = 'title'
ATTRIBUTE_MAPPING['street']['profile_field_name'] = 'address'
ATTRIBUTE_MAPPING['postalCode']['profile_field_name'] = 'postal_code'
ATTRIBUTE_MAPPING['mobile']['profile_field_name'] = 'mobile'
