#! /usr/bin/env python

''' Setup script for Polynum
'''

from setuptools import setup, find_packages
from setuptools.command.install_lib import install_lib as _install_lib
from distutils.command.build import build as _build
from distutils.command.sdist import sdist  as _sdist
from distutils.cmd import Command
import glob

class compile_translations(Command):
    description = 'compile message catalogs to MO files via django compilemessages'
    user_options = []

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        import os
        import sys
        from django.core.management.commands.compilemessages import \
            compile_messages
        for path in ['portail_citoyen'] + glob.glob('portail_citoyen/apps/*'):
            if path.endswith('.py'):
                continue
            curdir = os.getcwd()
            os.chdir(os.path.realpath(path))
            compile_messages(stderr=sys.stderr)
            os.chdir(curdir)

class build(_build):
    sub_commands = [('compile_translations', None)] + _build.sub_commands

class sdist(_sdist):
    sub_commands = [('compile_translations', None)] + _sdist.sub_commands

class install_lib(_install_lib):
    def run(self):
        self.run_command('compile_translations')
        _install_lib.run(self)

def get_version():
    import glob
    import re
    import os

    version = None
    for d in glob.glob('*'):
        if not os.path.isdir(d):
            continue
        module_file = os.path.join(d, '__init__.py')
        if not os.path.exists(module_file):
            continue
        for v in re.findall("""__version__ *= *['"](.*)['"]""",
                open(module_file).read()):
            assert version is None
            version = v
        if version:
            break
    assert version is not None
    if os.path.exists('.git'):
        import subprocess
        p = subprocess.Popen(['git','describe'],
                stdout=subprocess.PIPE)
        result = p.communicate()[0]
        assert p.returncode == 0, 'git returned non-zero'
        new_version = result.split()[0]
        assert new_version.split('-')[0] == version, '__version__ must match the last git annotated tag'
        version = new_version.replace('-', '.')
    return version


setup(name="portail_citoyen",
      version=get_version(),
      license="AGPLv3 or later",
      description="Portail citoyen",
      url="http://dev.entrouvert.org/projects/portail-citoyen/",
      author="Entr'ouvert",
      author_email="info@entrouvert.org",
      maintainer="Benjamin Dauvergne",
      maintainer_email="info@entrouvert.com",
      include_package_data=True,
      package_data={
          '': [
               'templates/**.html', 
               'static/**.png',
               'static/**.gif',
               'static/**.css',
               'static/**.js',
               'locale/**.mo', 
              ]
      },
      packages=find_packages(),
      scripts=('portail-citoyen',),
      install_requires=[
            'requests',
            'PIL',
            'feedparser',
            'django<1.6',
            'authentic2==2.0.3',
            'django-cms==2.4.0customuser',
      ],
      dependency_links = [
          'http://repos.entrouvert.org/authentic.git/snapshot/authentic-master.tar.gz#egg=authentic2-2.0.3',
          'http://repos.entrouvert.org/django-cms.git/snapshot/django-cms-develop.tar.gz#egg=django-cms-2.4.0customuser'
      ],
      cmdclass={'build': build, 'install_lib': install_lib,
          'compile_translations': compile_translations,
          'sdist': sdist},
)
